<template>
  <PIMTable
    rowKey="id"
    :column="columns"
    :tableData="dataList"
    :tableLoading="loading"
  >
  </PIMTable>
</template>

<script setup>
import { usePaginationApi } from "@/hooks/usePaginationApi";
import { productList } from "@/api/procurementManagement/procurementLedger.js";

defineOptions({
  name: "来票登记折叠表",
});

const {
  loading,
  filters,
  columns,
  dataList,
  pagination,
  getTableData,
  resetFilters,
} = usePaginationApi(
  productList,
  {
    salesLedgerId: undefined,
    type: 2,
  },
  [
    {
      label: "产品大类",
      prop: "productCategory",
    },
    {
      label: "规格型号",
      prop: "specificationModel",
    },
    {
      label: "单位",
      prop: "unit",
    },
    {
      label: "数量",
      prop: "quantity",
    },
    {
      label: "税率(%)",
      prop: "taxRate",
    },
    {
      label: "含税单价(元)",
      prop: "taxInclusiveUnitPrice",
      formatData: (val) => {
        return val ? parseFloat(val).toFixed(2) : "-";
      },
    },
    {
      label: "含税总价(元)",
      prop: "taxInclusiveTotalPrice",
      formatData: (val) => {
        return val ? parseFloat(val).toFixed(2) : "-";
      },
    },
    {
      label: "不含税总价(元)",
      prop: "taxExclusiveTotalPrice",
      formatData: (val) => {
        return val ? parseFloat(val).toFixed(2) : "-";
      },
    },
    {
      label: "本次来票金额(元)",
      prop: "ticketsAmount",
      formatData: (val) => {
        return val ? parseFloat(val).toFixed(2) : "-";
      },
    },
    {
      label: "未来票数",
      prop: "futureTickets",
    },
    {
      label: "未来票金额(元)",
      prop: "futureTicketsAmount",
      formatData: (val) => {
        return val ? parseFloat(val).toFixed(2) : "-";
      },
    },
  ],
  {},
  {},
  (data) => {
    dataList.value = data;
  }
);

const getList = (id) => {
  filters.salesLedgerId = id;
  getTableData();
};

defineExpose({
  getList,
});
</script>

<style lang="scss" scoped></style>
